h-resume parsing tests

# h-resume parsing tests ‐ change logs

The files in this directory where designed to test the parsing of h-resume.

## Change log:

- Updated JSON in order to reflect the parsing rules for src and alt attributes img elements - 24 June 2019 by Jan Sauer
- Update text output to be textContent non-trimmed for contact, education and work tests ‐ 29 May 2015 by Glenn Jones
- Remove empty value property in affiliation test. Also added missing title property to work test. ‐ 23 May 2015 by Glenn Jones
- Remove duplicate structures from items[] in affiliation, contact, education and work tests ‐ 23 May 2015 by Glenn Jones
- Broke old HTML format into small files to aid simpler testing ‐ 21 May 2015 by Glenn Jones
- Updated JSON examples so it always has the rel={} object as well as the items=[] array ‐ 21 November 2013 by Glenn Jones
- Removed competency tests ‐ 11 January 2013 by Glenn Jones
- Created ‐ 29 December 2012 by Glenn Jones

## Contributors:

- Glenn Jones
- Jan Sauer